CreateReplicationJobInputBuilder

Struct CreateReplicationJobInputBuilder 

#[non_exhaustive]
pub struct CreateReplicationJobInputBuilder { /* private fields */ }
Implementations

Source

impl CreateReplicationJobInputBuilder

pub fn server_id(self, input: impl Into<String>) -> Self

The ID of the server.

This field is required.
pub fn set_server_id(self, input: Option<String>) -> Self

The ID of the server.

pub fn get_server_id(&self) -> &Option<String>

The ID of the server.

pub fn seed_replication_time(self, input: DateTime) -> Self

The seed replication time.

This field is required.
pub fn set_seed_replication_time(self, input: Option<DateTime>) -> Self

The seed replication time.

pub fn get_seed_replication_time(&self) -> &Option<DateTime>

The seed replication time.

pub fn frequency(self, input: i32) -> Self

The time between consecutive replication runs, in hours.

pub fn set_frequency(self, input: Option<i32>) -> Self

The time between consecutive replication runs, in hours.

pub fn get_frequency(&self) -> &Option<i32>

The time between consecutive replication runs, in hours.

pub fn run_once(self, input: bool) -> Self

Indicates whether to run the replication job one time.

pub fn set_run_once(self, input: Option<bool>) -> Self

Indicates whether to run the replication job one time.

pub fn get_run_once(&self) -> &Option<bool>

Indicates whether to run the replication job one time.

pub fn license_type(self, input: LicenseType) -> Self

The license type to be used for the AMI created by a successful replication run.

pub fn set_license_type(self, input: Option<LicenseType>) -> Self

The license type to be used for the AMI created by a successful replication run.

pub fn get_license_type(&self) -> &Option<LicenseType>

The license type to be used for the AMI created by a successful replication run.

pub fn role_name(self, input: impl Into<String>) -> Self

The name of the IAM role to be used by the Server Migration Service.

pub fn set_role_name(self, input: Option<String>) -> Self

The name of the IAM role to be used by the Server Migration Service.

pub fn get_role_name(&self) -> &Option<String>

The name of the IAM role to be used by the Server Migration Service.

pub fn description(self, input: impl Into<String>) -> Self

The description of the replication job.

pub fn set_description(self, input: Option<String>) -> Self

The description of the replication job.

pub fn get_description(&self) -> &Option<String>

The description of the replication job.

pub fn number_of_recent_amis_to_keep(self, input: i32) -> Self

The maximum number of SMS-created AMIs to retain. The oldest is deleted after the maximum number is reached and a new AMI is created.

pub fn set_number_of_recent_amis_to_keep(self, input: Option<i32>) -> Self

The maximum number of SMS-created AMIs to retain. The oldest is deleted after the maximum number is reached and a new AMI is created.

pub fn get_number_of_recent_amis_to_keep(&self) -> &Option<i32>

The maximum number of SMS-created AMIs to retain. The oldest is deleted after the maximum number is reached and a new AMI is created.

pub fn encrypted(self, input: bool) -> Self

Indicates whether the replication job produces encrypted AMIs.

pub fn set_encrypted(self, input: Option<bool>) -> Self

Indicates whether the replication job produces encrypted AMIs.

pub fn get_encrypted(&self) -> &Option<bool>

Indicates whether the replication job produces encrypted AMIs.

pub fn kms_key_id(self, input: impl Into<String>) -> Self

The ID of the KMS key for replication jobs that produce encrypted AMIs. This value can be any of the following:

  • KMS key ID

  • KMS key alias

  • ARN referring to the KMS key ID

  • ARN referring to the KMS key alias

If encrypted is true but a KMS key ID is not specified, the customer's default KMS key for Amazon EBS is used.

pub fn set_kms_key_id(self, input: Option<String>) -> Self

The ID of the KMS key for replication jobs that produce encrypted AMIs. This value can be any of the following:

  • KMS key ID

  • KMS key alias

  • ARN referring to the KMS key ID

  • ARN referring to the KMS key alias

If encrypted is true but a KMS key ID is not specified, the customer's default KMS key for Amazon EBS is used.

pub fn get_kms_key_id(&self) -> &Option<String>

The ID of the KMS key for replication jobs that produce encrypted AMIs. This value can be any of the following:

  • KMS key ID

  • KMS key alias

  • ARN referring to the KMS key ID

  • ARN referring to the KMS key alias

If encrypted is true but a KMS key ID is not specified, the customer's default KMS key for Amazon EBS is used.

pub fn build(self) -> Result<CreateReplicationJobInput, BuildError>

Consumes the builder and constructs a CreateReplicationJobInput.

Source

impl CreateReplicationJobInputBuilder

pub async fn send_with( self, client: &Client, ) -> Result<CreateReplicationJobOutput, SdkError<CreateReplicationJobError, HttpResponse>>

Sends a request with this input using the given client.