#[non_exhaustive]pub struct PutAppReplicationConfigurationInput {
pub app_id: Option<String>,
pub server_group_replication_configurations: Option<Vec<ServerGroupReplicationConfiguration>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.app_id: Option<String>The ID of the application.
server_group_replication_configurations: Option<Vec<ServerGroupReplicationConfiguration>>Information about the replication configurations for server groups in the application.
Implementations
Sourceimpl PutAppReplicationConfigurationInput
impl PutAppReplicationConfigurationInput
Sourcepub fn server_group_replication_configurations(
&self,
) -> &[ServerGroupReplicationConfiguration]
pub fn server_group_replication_configurations( &self, ) -> &[ServerGroupReplicationConfiguration]
Information about the replication configurations for server groups in the application.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .server_group_replication_configurations.is_none().
Sourceimpl PutAppReplicationConfigurationInput
impl PutAppReplicationConfigurationInput
Sourcepub fn builder() -> PutAppReplicationConfigurationInputBuilder
pub fn builder() -> PutAppReplicationConfigurationInputBuilder
Creates a new builder-style object to manufacture PutAppReplicationConfigurationInput.