#[non_exhaustive]pub struct Connector {
pub connector_id: Option<String>,
pub version: Option<String>,
pub status: Option<ConnectorStatus>,
pub capability_list: Option<Vec<ConnectorCapability>>,
pub vm_manager_name: Option<String>,
pub vm_manager_type: Option<VmManagerType>,
pub vm_manager_id: Option<String>,
pub ip_address: Option<String>,
pub mac_address: Option<String>,
pub associated_on: Option<DateTime>,
}Expand description
Represents a connector.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.connector_id: Option<String>The ID of the connector.
version: Option<String>The connector version.
status: Option<ConnectorStatus>The status of the connector.
capability_list: Option<Vec<ConnectorCapability>>The capabilities of the connector.
vm_manager_name: Option<String>The name of the VM manager.
vm_manager_type: Option<VmManagerType>The VM management product.
vm_manager_id: Option<String>The ID of the VM manager.
ip_address: Option<String>The IP address of the connector.
mac_address: Option<String>The MAC address of the connector.
associated_on: Option<DateTime>The time the connector was associated.
Implementations
Sourceimpl Connector
impl Connector
Sourcepub fn connector_id(&self) -> Option<&str>
pub fn connector_id(&self) -> Option<&str>
The ID of the connector.
Sourcepub fn status(&self) -> Option<&ConnectorStatus>
pub fn status(&self) -> Option<&ConnectorStatus>
The status of the connector.
Sourcepub fn capability_list(&self) -> &[ConnectorCapability]
pub fn capability_list(&self) -> &[ConnectorCapability]
The capabilities of the connector.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .capability_list.is_none().
Sourcepub fn vm_manager_name(&self) -> Option<&str>
pub fn vm_manager_name(&self) -> Option<&str>
The name of the VM manager.
Sourcepub fn vm_manager_type(&self) -> Option<&VmManagerType>
pub fn vm_manager_type(&self) -> Option<&VmManagerType>
The VM management product.
Sourcepub fn vm_manager_id(&self) -> Option<&str>
pub fn vm_manager_id(&self) -> Option<&str>
The ID of the VM manager.
Sourcepub fn ip_address(&self) -> Option<&str>
pub fn ip_address(&self) -> Option<&str>
The IP address of the connector.
Sourcepub fn mac_address(&self) -> Option<&str>
pub fn mac_address(&self) -> Option<&str>
The MAC address of the connector.
Sourcepub fn associated_on(&self) -> Option<&DateTime>
pub fn associated_on(&self) -> Option<&DateTime>
The time the connector was associated.