ServerLaunchConfiguration

Struct ServerLaunchConfiguration 

#[non_exhaustive]
pub struct ServerLaunchConfiguration { pub server: Option<Server>, pub logical_id: Option<String>, pub vpc: Option<String>, pub subnet: Option<String>, pub security_group: Option<String>, pub ec2_key_name: Option<String>, pub user_data: Option<UserData>, pub instance_type: Option<String>, pub associate_public_ip_address: Option<bool>, pub iam_instance_profile_name: Option<String>, pub configure_script: Option<S3Location>, pub configure_script_type: Option<ScriptType>, }
Launch configuration for a server.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
server: Option<Server>

The ID of the server with which the launch configuration is associated.

logical_id: Option<String>

The logical ID of the server in the CloudFormation template.

vpc: Option<String>

The ID of the VPC into which the server should be launched.

subnet: Option<String>

The ID of the subnet the server should be launched into.

security_group: Option<String>

The ID of the security group that applies to the launched server.

ec2_key_name: Option<String>

The name of the Amazon EC2 SSH key to be used for connecting to the launched server.

user_data: Option<UserData>

Location of the user-data script to be executed when launching the server.

instance_type: Option<String>

The instance type to use when launching the server.

associate_public_ip_address: Option<bool>

Indicates whether a publicly accessible IP address is created when launching the server.

iam_instance_profile_name: Option<String>

The name of the IAM instance profile.

configure_script: Option<S3Location>

Location of an Amazon S3 object.

configure_script_type: Option<ScriptType>

The type of configuration script.

Implementations

Source

impl ServerLaunchConfiguration

pub fn server(&self) -> Option<&Server>

The ID of the server with which the launch configuration is associated.

pub fn logical_id(&self) -> Option<&str>

The logical ID of the server in the CloudFormation template.

pub fn vpc(&self) -> Option<&str>

The ID of the VPC into which the server should be launched.

pub fn subnet(&self) -> Option<&str>

The ID of the subnet the server should be launched into.

pub fn security_group(&self) -> Option<&str>

The ID of the security group that applies to the launched server.

pub fn ec2_key_name(&self) -> Option<&str>

The name of the Amazon EC2 SSH key to be used for connecting to the launched server.

pub fn user_data(&self) -> Option<&UserData>

Location of the user-data script to be executed when launching the server.

pub fn instance_type(&self) -> Option<&str>

The instance type to use when launching the server.

pub fn associate_public_ip_address(&self) -> Option<bool>

Indicates whether a publicly accessible IP address is created when launching the server.

pub fn iam_instance_profile_name(&self) -> Option<&str>

The name of the IAM instance profile.

pub fn configure_script(&self) -> Option<&S3Location>

Location of an Amazon S3 object.

pub fn configure_script_type(&self) -> Option<&ScriptType>

The type of configuration script.

Source

impl ServerLaunchConfiguration

pub fn builder() -> ServerLaunchConfigurationBuilder

Creates a new builder-style object to manufacture ServerLaunchConfiguration.