ServerReplicationParameters

Struct ServerReplicationParameters 

#[non_exhaustive]
pub struct ServerReplicationParameters { pub seed_time: Option<DateTime>, pub frequency: Option<i32>, pub run_once: Option<bool>, pub license_type: Option<LicenseType>, pub number_of_recent_amis_to_keep: Option<i32>, pub encrypted: Option<bool>, pub kms_key_id: Option<String>, }
The replication parameters for replicating a server.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
seed_time: Option<DateTime>

The seed time for creating a replication job for the server.

frequency: Option<i32>

The frequency of creating replication jobs for the server.

run_once: Option<bool>

Indicates whether to run the replication job one time.

license_type: Option<LicenseType>

The license type for creating a replication job for the server.

number_of_recent_amis_to_keep: Option<i32>

The number of recent AMIs to keep when creating a replication job for this server.

encrypted: Option<bool>

Indicates whether the replication job produces encrypted AMIs.

kms_key_id: Option<String>

The ID of the KMS key for replication jobs that produce encrypted AMIs. This value can be any of the following:

  • KMS key ID

  • KMS key alias

  • ARN referring to the KMS key ID

  • ARN referring to the KMS key alias

If encrypted is enabled but a KMS key ID is not specified, the customer's default KMS key for Amazon EBS is used.

Implementations

Source

impl ServerReplicationParameters

pub fn seed_time(&self) -> Option<&DateTime>

The seed time for creating a replication job for the server.

pub fn frequency(&self) -> Option<i32>

The frequency of creating replication jobs for the server.

pub fn run_once(&self) -> Option<bool>

Indicates whether to run the replication job one time.

pub fn license_type(&self) -> Option<&LicenseType>

The license type for creating a replication job for the server.

pub fn number_of_recent_amis_to_keep(&self) -> Option<i32>

The number of recent AMIs to keep when creating a replication job for this server.

pub fn encrypted(&self) -> Option<bool>

Indicates whether the replication job produces encrypted AMIs.

pub fn kms_key_id(&self) -> Option<&str>

The ID of the KMS key for replication jobs that produce encrypted AMIs. This value can be any of the following:

  • KMS key ID

  • KMS key alias

  • ARN referring to the KMS key ID

  • ARN referring to the KMS key alias

If encrypted is enabled but a KMS key ID is not specified, the customer's default KMS key for Amazon EBS is used.

Source

impl ServerReplicationParameters

pub fn builder() -> ServerReplicationParametersBuilder

Creates a new builder-style object to manufacture ServerReplicationParameters.